aboutsummaryrefslogtreecommitdiff
path: root/syncapi/routing
diff options
context:
space:
mode:
Diffstat (limited to 'syncapi/routing')
-rw-r--r--syncapi/routing/state.go7
1 files changed, 3 insertions, 4 deletions
diff --git a/syncapi/routing/state.go b/syncapi/routing/state.go
index dbee267d..cf67f752 100644
--- a/syncapi/routing/state.go
+++ b/syncapi/routing/state.go
@@ -22,7 +22,6 @@ import (
"github.com/matrix-org/dendrite/clientapi/jsonerror"
"github.com/matrix-org/dendrite/syncapi/storage"
"github.com/matrix-org/dendrite/syncapi/types"
- "github.com/matrix-org/gomatrix"
"github.com/matrix-org/gomatrixserverlib"
"github.com/matrix-org/util"
log "github.com/sirupsen/logrus"
@@ -45,10 +44,10 @@ func OnIncomingStateRequest(req *http.Request, db storage.Database, roomID strin
// TODO(#287): Auth request and handle the case where the user has left (where
// we should return the state at the poin they left)
- stateFilterPart := gomatrix.DefaultFilterPart()
- // TODO: stateFilterPart should not limit the number of state events (or only limits abusive number of events)
+ stateFilter := gomatrixserverlib.DefaultStateFilter()
+ // TODO: stateFilter should not limit the number of state events (or only limits abusive number of events)
- stateEvents, err := db.GetStateEventsForRoom(req.Context(), roomID, &stateFilterPart)
+ stateEvents, err := db.GetStateEventsForRoom(req.Context(), roomID, &stateFilter)
if err != nil {
return httputil.LogThenError(req, err)
}